## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup, eval = FALSE------------------------------------------------------
#  if (!require("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  BiocManager::install("pathwrap")

## ----installation, eval = FALSE-----------------------------------------------
#  library(pathwrap)
#  data(anntpkglist, package = "pathwrap")
#  #replace Homo sapiens with scientific name of mouse, Mus musculus for mouse data
#  genomepkg <- anntpkglist$genome[which(anntpkglist$species == "Homo sapiens")]
#  anntpkg <- anntpkglist$annotate[which(anntpkglist$species == "Homo sapiens")]
#  #BiocManager::install(genomepkg)
#  #BiocManager::install(anntpkg)

## ----documentation, eval = FALSE----------------------------------------------
#  browseVignettes("pathwrap")

## ----wrapper, eval =TRUE------------------------------------------------------
# create a phenofile
phenofile <- tempfile("hellotmpphenofile.txt")
# create columns for phenofile, this is for SE data
# col.names should be SampleName, FileName and Class for SE data
library(stringr)
FileName <- list.files(
    file.path(system.file(
        package = "pathwrap"
    ), "extdata"),
    full.names = TRUE,
    pattern = "fastq.gz"
)
patternmy <- c(dirname(FileName[1]), "_sub.fastq.gz")
SampleName <- str_replace_all(
    pattern = paste0(dirname(FileName)[1], "/|_sub.fastq.gz"),
    string = list.files(
        file.path(
            system.file(package = "pathwrap"), "extdata"
        ),
        full.names = TRUE, pattern = "fastq.gz"
    ), ""
)
Class <- c("A", "B", "A", "B")
# write the columns in the phenofile
write.table(as.data.frame(cbind(SampleName, FileName, Class)),
    file = phenofile, sep = "\t", row.names = FALSE,
    col.names = TRUE, quote = FALSE
)

## ----sampleFileSingle, echo=FALSE, results="asis"-----------------------------
cat(paste(
    readLines(system.file(
        package = "pathwrap",
        "extdata", "phenofile_SE.txt"
    )),
    collapse = "\n"
))

## ----sampleFilePaired, echo=FALSE, results="asis"-----------------------------
cat(paste(
    readLines(system.file(
        package = "pathwrap",
        "extdata", "phenofile_PE.txt"
    )),
    collapse = "\n"
))

## ----sampleFilepairedexperiment, echo = FALSE, results="asis"-----------------
cat(paste(
    readLines(system.file(
        package = "pathwrap",
        "extdata", "phenofile_SE_paired.txt"
    )),
    collapse = "\n"
))

## ----demorun, eval = FALSE----------------------------------------------------
#  # create directory to store results
#  Results <- tempdir()
#  csamp <- c(1,2)
#  cref <- c(3,4)
#  cdatapath <- file.path(system.file(package = "pathwrap"), "extdata",
#                           "example_cpd_data.tsv")
#  if (interactive()){pathwrap(
#      ref.dir = NA, phenofile = phenofile,
#      outdir = Results, entity = "Mus musculus", corenum = 16,
#      compare = "as.group",  keep_tmp = TRUE,startover = TRUE,
#      diff.tool = "DESeq2", aligner = "Rhisat2", mode = "combined",
#      cdatapath = cdatapath, cref= cref, csamp = csamp, ccompare = "paired"
#  )}

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

